@@ -1,4 +1,7 @@
-/* Copyright (C) 2015-2017 Jason A. Donenfeld <Jason@zx2c4.com>. All Rights Reserved. */
+/* SPDX-License-Identifier: GPL-2.0 */
+/*
+ * Copyright (C) 2015-2019 Jason A. Donenfeld <Jason@zx2c4.com>. All Rights Reserved.
+ */
 
 #ifndef IPC_H
 #define IPC_H
@@ -10,6 +13,5 @@ struct wgdevice;
 int ipc_set_device(struct wgdevice *dev);
 int ipc_get_device(struct wgdevice **dev, const char *interface);
 char *ipc_list_devices(void);
-bool ipc_has_device(const char *interface);
 
 #endif
